==> zio-aws-opensearch_2.12-6.20.83.1-sources.jar: zio/aws/opensearch/model/PackageDetails.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  PackageName,
  PackageDescription,
  CreatedAt,
  PackageVersion,
  LastUpdated,
  PackageID
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class PackageDetails(
    packageID: Optional[PackageID] = Optional.Absent,
    packageName: Optional[PackageName] = Optional.Absent,
    packageType: Optional[zio.aws.opensearch.model.PackageType] =
      Optional.Absent,
    packageDescription: Optional[PackageDescription] = Optional.Absent,
    packageStatus: Optional[zio.aws.opensearch.model.PackageStatus] =
      Optional.Absent,
    createdAt: Optional[CreatedAt] = Optional.Absent,
    lastUpdatedAt: Optional[LastUpdated] = Optional.Absent,
    availablePackageVersion: Optional[PackageVersion] = Optional.Absent,
    errorDetails: Optional[zio.aws.opensearch.model.ErrorDetails] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.PackageDetails = {
    import PackageDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.PackageDetails
      .builder()
      .optionallyWith(
        packageID.map(value => PackageID.unwrap(value): java.lang.String)
      )(_.packageID)
      .optionallyWith(
        packageName.map(value => PackageName.unwrap(value): java.lang.String)
      )(_.packageName)
      .optionallyWith(packageType.map(value => value.unwrap))(_.packageType)
      .optionallyWith(
        packageDescription.map(value =>
          PackageDescription.unwrap(value): java.lang.String
        )
      )(_.packageDescription)
      .optionallyWith(packageStatus.map(value => value.unwrap))(_.packageStatus)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdated.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(
        availablePackageVersion.map(value =>
          PackageVersion.unwrap(value): java.lang.String
        )
      )(_.availablePackageVersion)
      .optionallyWith(errorDetails.map(value => value.buildAwsValue()))(
        _.errorDetails
      )
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.PackageDetails.ReadOnly =
    zio.aws.opensearch.model.PackageDetails.wrap(buildAwsValue())
}
object PackageDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.PackageDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.PackageDetails =
      zio.aws.opensearch.model.PackageDetails(
        packageID.map(value => value),
        packageName.map(value => value),
        packageType.map(value => value),
        packageDescription.map(value => value),
        packageStatus.map(value => value),
        createdAt.map(value => value),
        lastUpdatedAt.map(value => value),
        availablePackageVersion.map(value => value),
        errorDetails.map(value => value.asEditable)
      )
    def packageID: Optional[PackageID]
    def packageName: Optional[PackageName]
    def packageType: Optional[zio.aws.opensearch.model.PackageType]
    def packageDescription: Optional[PackageDescription]
    def packageStatus: Optional[zio.aws.opensearch.model.PackageStatus]
    def createdAt: Optional[CreatedAt]
    def lastUpdatedAt: Optional[LastUpdated]
    def availablePackageVersion: Optional[PackageVersion]
    def errorDetails: Optional[zio.aws.opensearch.model.ErrorDetails.ReadOnly]
    def getPackageID: ZIO[Any, AwsError, PackageID] =
      AwsError.unwrapOptionField("packageID", packageID)
    def getPackageName: ZIO[Any, AwsError, PackageName] =
      AwsError.unwrapOptionField("packageName", packageName)
    def getPackageType
        : ZIO[Any, AwsError, zio.aws.opensearch.model.PackageType] =
      AwsError.unwrapOptionField("packageType", packageType)
    def getPackageDescription: ZIO[Any, AwsError, PackageDescription] =
      AwsError.unwrapOptionField("packageDescription", packageDescription)
    def getPackageStatus
        : ZIO[Any, AwsError, zio.aws.opensearch.model.PackageStatus] =
      AwsError.unwrapOptionField("packageStatus", packageStatus)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdated] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getAvailablePackageVersion: ZIO[Any, AwsError, PackageVersion] =
      AwsError.unwrapOptionField(
        "availablePackageVersion",
        availablePackageVersion
      )
    def getErrorDetails
        : ZIO[Any, AwsError, zio.aws.opensearch.model.ErrorDetails.ReadOnly] =
      AwsError.unwrapOptionField("errorDetails", errorDetails)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.PackageDetails
  ) extends zio.aws.opensearch.model.PackageDetails.ReadOnly {
    override val packageID: Optional[PackageID] = zio.aws.core.internal
      .optionalFromNullable(impl.packageID())
      .map(value => zio.aws.opensearch.model.primitives.PackageID(value))
    override val packageName: Optional[PackageName] = zio.aws.core.internal
      .optionalFromNullable(impl.packageName())
      .map(value => zio.aws.opensearch.model.primitives.PackageName(value))
    override val packageType: Optional[zio.aws.opensearch.model.PackageType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageType())
        .map(value => zio.aws.opensearch.model.PackageType.wrap(value))
    override val packageDescription: Optional[PackageDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageDescription())
        .map(value =>
          zio.aws.opensearch.model.primitives.PackageDescription(value)
        )
    override val packageStatus
        : Optional[zio.aws.opensearch.model.PackageStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageStatus())
        .map(value => zio.aws.opensearch.model.PackageStatus.wrap(value))
    override val createdAt: Optional[CreatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.opensearch.model.primitives.CreatedAt(value))
    override val lastUpdatedAt: Optional[LastUpdated] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedAt())
      .map(value => zio.aws.opensearch.model.primitives.LastUpdated(value))
    override val availablePackageVersion: Optional[PackageVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availablePackageVersion())
        .map(value => zio.aws.opensearch.model.primitives.PackageVersion(value))
    override val errorDetails
        : Optional[zio.aws.opensearch.model.ErrorDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorDetails())
        .map(value => zio.aws.opensearch.model.ErrorDetails.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.PackageDetails
  ): zio.aws.opensearch.model.PackageDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opensearch_3-5.17.202.1-sources.jar: zio/aws/opensearch/model/PackageDetails.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  PackageName,
  PackageDescription,
  CreatedAt,
  PackageVersion,
  LastUpdated,
  PackageID
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters.*
final case class PackageDetails(
    packageID: Optional[PackageID] = Optional.Absent,
    packageName: Optional[PackageName] = Optional.Absent,
    packageType: Optional[zio.aws.opensearch.model.PackageType] =
      Optional.Absent,
    packageDescription: Optional[PackageDescription] = Optional.Absent,
    packageStatus: Optional[zio.aws.opensearch.model.PackageStatus] =
      Optional.Absent,
    createdAt: Optional[CreatedAt] = Optional.Absent,
    lastUpdatedAt: Optional[LastUpdated] = Optional.Absent,
    availablePackageVersion: Optional[PackageVersion] = Optional.Absent,
    errorDetails: Optional[zio.aws.opensearch.model.ErrorDetails] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.PackageDetails = {
    import PackageDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.PackageDetails
      .builder()
      .optionallyWith(
        packageID.map(value => PackageID.unwrap(value): java.lang.String)
      )(_.packageID)
      .optionallyWith(
        packageName.map(value => PackageName.unwrap(value): java.lang.String)
      )(_.packageName)
      .optionallyWith(packageType.map(value => value.unwrap))(_.packageType)
      .optionallyWith(
        packageDescription.map(value =>
          PackageDescription.unwrap(value): java.lang.String
        )
      )(_.packageDescription)
      .optionallyWith(packageStatus.map(value => value.unwrap))(_.packageStatus)
      .optionallyWith(createdAt.map(value => CreatedAt.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdated.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(
        availablePackageVersion.map(value =>
          PackageVersion.unwrap(value): java.lang.String
        )
      )(_.availablePackageVersion)
      .optionallyWith(errorDetails.map(value => value.buildAwsValue()))(
        _.errorDetails
      )
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.PackageDetails.ReadOnly =
    zio.aws.opensearch.model.PackageDetails.wrap(buildAwsValue())
}
object PackageDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.PackageDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.PackageDetails =
      zio.aws.opensearch.model.PackageDetails(
        packageID.map(value => value),
        packageName.map(value => value),
        packageType.map(value => value),
        packageDescription.map(value => value),
        packageStatus.map(value => value),
        createdAt.map(value => value),
        lastUpdatedAt.map(value => value),
        availablePackageVersion.map(value => value),
        errorDetails.map(value => value.asEditable)
      )
    def packageID: Optional[PackageID]
    def packageName: Optional[PackageName]
    def packageType: Optional[zio.aws.opensearch.model.PackageType]
    def packageDescription: Optional[PackageDescription]
    def packageStatus: Optional[zio.aws.opensearch.model.PackageStatus]
    def createdAt: Optional[CreatedAt]
    def lastUpdatedAt: Optional[LastUpdated]
    def availablePackageVersion: Optional[PackageVersion]
    def errorDetails: Optional[zio.aws.opensearch.model.ErrorDetails.ReadOnly]
    def getPackageID: ZIO[Any, AwsError, PackageID] =
      AwsError.unwrapOptionField("packageID", packageID)
    def getPackageName: ZIO[Any, AwsError, PackageName] =
      AwsError.unwrapOptionField("packageName", packageName)
    def getPackageType
        : ZIO[Any, AwsError, zio.aws.opensearch.model.PackageType] =
      AwsError.unwrapOptionField("packageType", packageType)
    def getPackageDescription: ZIO[Any, AwsError, PackageDescription] =
      AwsError.unwrapOptionField("packageDescription", packageDescription)
    def getPackageStatus
        : ZIO[Any, AwsError, zio.aws.opensearch.model.PackageStatus] =
      AwsError.unwrapOptionField("packageStatus", packageStatus)
    def getCreatedAt: ZIO[Any, AwsError, CreatedAt] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdated] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getAvailablePackageVersion: ZIO[Any, AwsError, PackageVersion] =
      AwsError.unwrapOptionField(
        "availablePackageVersion",
        availablePackageVersion
      )
    def getErrorDetails
        : ZIO[Any, AwsError, zio.aws.opensearch.model.ErrorDetails.ReadOnly] =
      AwsError.unwrapOptionField("errorDetails", errorDetails)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.PackageDetails
  ) extends zio.aws.opensearch.model.PackageDetails.ReadOnly {
    override val packageID: Optional[PackageID] = zio.aws.core.internal
      .optionalFromNullable(impl.packageID())
      .map(value => zio.aws.opensearch.model.primitives.PackageID(value))
    override val packageName: Optional[PackageName] = zio.aws.core.internal
      .optionalFromNullable(impl.packageName())
      .map(value => zio.aws.opensearch.model.primitives.PackageName(value))
    override val packageType: Optional[zio.aws.opensearch.model.PackageType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageType())
        .map(value => zio.aws.opensearch.model.PackageType.wrap(value))
    override val packageDescription: Optional[PackageDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageDescription())
        .map(value =>
          zio.aws.opensearch.model.primitives.PackageDescription(value)
        )
    override val packageStatus
        : Optional[zio.aws.opensearch.model.PackageStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.packageStatus())
        .map(value => zio.aws.opensearch.model.PackageStatus.wrap(value))
    override val createdAt: Optional[CreatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.opensearch.model.primitives.CreatedAt(value))
    override val lastUpdatedAt: Optional[LastUpdated] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedAt())
      .map(value => zio.aws.opensearch.model.primitives.LastUpdated(value))
    override val availablePackageVersion: Optional[PackageVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.availablePackageVersion())
        .map(value => zio.aws.opensearch.model.primitives.PackageVersion(value))
    override val errorDetails
        : Optional[zio.aws.opensearch.model.ErrorDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.errorDetails())
        .map(value => zio.aws.opensearch.model.ErrorDetails.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.PackageDetails
  ): zio.aws.opensearch.model.PackageDetails.ReadOnly = new Wrapper(impl)
}
